# Load the data
ecls_wide<-read.table("C:/GRE2016/Data/ecls_wght.dat", na.string='.')

# Give the variable names
names(ecls_wide)<-c('id','female',
                         'math1','math2','math3','math4',
                         'read1','read2','read3','read4',
                         'gk1','gk2','gk3','gk4',
                         'hght1','hght2','hght3','hght4',
                         'wght1','wght2','wght3','wght4')

library(OpenMx)

############# Linear Growth Model #############
lgm <- mxModel("Linear Growth", type="RAM", 
 mxData(observed=ecls_wide, type="raw"),
 manifestVars=c("wght1","wght2","wght3","wght4"),
 latentVars=c("eta_1","eta_2"),

# residual variances  
mxPath(from=c("wght1","wght2","wght3","wght4"), arrows=2, 
 free=TRUE, values=6, labels="theta"),

# latent variances and covariance  
mxPath(from=c("eta_1","eta_2"), arrows=2, connect="unique.pairs",
 free=TRUE, values=c(40, 7, 3), labels=c("psi_11", "psi_12", "psi_22")),

# intercept loadings
mxPath(from="eta_1", to=c("wght1","wght2","wght3","wght4"), arrows=1, 
 free=FALSE, values=1),

# slope loadings  
mxPath(from="eta_2", to=c("wght1","wght2","wght3","wght4"), arrows=1,
 free=FALSE, values=c(0, .5, 1, 1.5)),

# latent variable means  
mxPath(from="one", to=c("eta_1", "eta_2"), arrows=1,
 free=TRUE, values=c(44, 6), labels=c("alpha_1_c1", "alpha_2_c1"))

) # close model 

lgm.fit <- mxRun(lgm)

summary(lgm.fit)

#free parameters:
#        name matrix   row   col  Estimate Std.Error
#1      theta      S wght1 wght1  5.551071 0.1751775
#2     psi_11      S eta_1 eta_1 72.030721 3.2715300
#3     psi_12      S eta_1 eta_2 21.694559 1.1789019
#4     psi_22      S eta_2 eta_2 10.279580 0.6677825
#5 alpha_1_c1      M     1 eta_1 45.786061 0.2650637
#6 alpha_2_c1      M     1 eta_2  6.628125 0.1186077
#
#observed statistics:  4141 
#estimated parameters:  6 
#degrees of freedom:  4135 
#-2 log likelihood:  23988.85 
#number of observations:  1083 
#Information Criteria: 
#      |  df Penalty  |  Parameters Penalty  |  Sample-Size Adjusted
#AIC:      15718.846               24000.85                       NA
#BIC:      -4904.426               24030.77                 24011.71
#Some of your fit indices are missing.
#  To get them, fit saturated and independence models, and include them with
#  summary(yourModel, SaturatedLikelihood=..., IndependenceLikelihood=...). 
#timestamp: 2014-10-20 20:59:08 
#wall clock time: 0.1560092 secs 
#optimizer:  CSOLNP 
#OpenMx version number: 2.0.0.3838 
#Need help?  See help(mxSummary) 


############# 2-Class Growth Mixture Model - Means #############
class1 <- mxModel("Class1", type="RAM", 
 manifestVars=c("wght1","wght2","wght3","wght4"),
 latentVars=c("eta_1","eta_2"),

# residual variances  
mxPath(from=c("wght1","wght2","wght3","wght4"), arrows=2, 
 free=TRUE, values=6, labels="theta"),

# latent variances and covariance  
mxPath(from=c("eta_1","eta_2"), arrows=2, connect="unique.pairs",
 free=TRUE, values=c(40, 7, 3), labels=c("psi_11", "psi_12", "psi_22")),

# intercept loadings
mxPath(from="eta_1", to=c("wght1","wght2","wght3","wght4"), arrows=1, 
 free=FALSE, values=1),

# slope loadings  
mxPath(from="eta_2", to=c("wght1","wght2","wght3","wght4"), arrows=1,
 free=FALSE, values=c(0, .5, 1, 1.5)),

# latent variable means  
mxPath(from="one", to=c("eta_1", "eta_2"), arrows=1,
 free=TRUE, values=c(44, 6), labels=c("alpha_1_c1", "alpha_2_c1")),

# ML Fit Function to run for each individual  
mxFitFunctionML(vector=TRUE)
) # close model for class 1

class2 <- mxModel(class1,
# latent means  
mxPath(from="one", to=c("eta_1", "eta_2"), arrows=1, 
 free=TRUE, values=c(65, 15), labels=c("alpha_1_c2", "alpha_2_c2")),
 
 name="Class2") # close model

classRP <- mxMatrix("Full", 2, 1, free=c(TRUE, FALSE),
 values=1, lbound=0.001, labels = c("p1", "p2"), name="RProps")

classP <- mxAlgebra(RProps %x% (1 / sum(RProps)), name="Props")

algObj <- mxAlgebra(-2*sum( log(Props[1,1] %x% Class1.objective + Props[2,1] %x% Class2.objective)), name="mixtureObj") 

obj <- mxFitFunctionAlgebra("mixtureObj")

gmm.2.means <- mxModel("2Class Means Growth Mixture Model",
 mxData(observed=ecls_wide, type="raw"),
 class1, class2, classRP, classP, algObj, obj)

gmm.2.means.fit <- mxRun(gmm.2.means)

summary(gmm.2.means.fit)

#free parameters:
#        name   matrix   row   col  Estimate Std.Error lbound ubound
#1         p1   RProps     1     1 10.722685 1.4383818  0.001       
#2      theta Class1.S wght1 wght1  5.574039 0.1757217              
#3     psi_11 Class1.S eta_1 eta_1 40.082067 2.1323574              
#4     psi_12 Class1.S eta_1 eta_2  6.694213 0.6425100              
#5     psi_22 Class1.S eta_2 eta_2  3.117379 0.4613173              
#6 alpha_1_c1 Class1.M     1 eta_1 44.060436 0.2233393              
#7 alpha_2_c1 Class1.M     1 eta_2  5.818469 0.1006631              
#8 alpha_1_c2 Class2.M     1 eta_1 64.305698 1.0543901              
#9 alpha_2_c2 Class2.M     1 eta_2 15.300968 0.3768798              
#
#observed statistics:  4141 
#estimated parameters:  9 
#degrees of freedom:  4132 
#-2 log likelihood:  23601.06 
#saturated -2 log likelihood:  NA 
#number of observations:  1083 
#chi-square:  NA 
#p:  NA 
#Information Criteria: 
#     df Penalty Parameters Penalty Sample-Size Adjusted
#AIC:  15337.058           23619.06                   NA
#BIC:  -5271.252           23663.95             23635.36
#CFI: NA 
#TLI: NA 
#RMSEA:  NA 
#timestamp: 2014-06-17 21:53:09 
#frontend time: 0.1100118 secs 
#backend time: 0.7350731 secs 
#independent submodels time: 0 secs 
#wall clock time: 0.8450849 secs 
#cpu time: 0.8450849 secs 
#OpenMx version number: 999.0.0-3473 



############# 3-Class Growth Mixture Model - Means #############
class1 <- mxModel("Class1", type="RAM", 
 manifestVars=c("wght1","wght2","wght3","wght4"),
 latentVars=c("eta_1","eta_2"),

# residual variances  
mxPath(from=c("wght1","wght2","wght3","wght4"), arrows=2, 
 free=TRUE, values=6, labels="theta"),

# latent variances and covariance  
mxPath(from=c("eta_1","eta_2"), arrows=2, connect="unique.pairs",
 free=TRUE, values=c(40, 7, 3), labels=c("psi_11", "psi_12", "psi_22")),

# intercept loadings
mxPath(from="eta_1", to=c("wght1","wght2","wght3","wght4"), arrows=1, 
 free=FALSE, values=1),

# slope loadings  
mxPath(from="eta_2", to=c("wght1","wght2","wght3","wght4"), arrows=1,
 free=FALSE, values=c(0, .5, 1, 1.5)),

# latent variable means  
mxPath(from="one", to=c("eta_1", "eta_2"), arrows=1,
 free=TRUE, values=c(44, 6), labels=c("alpha_1_c1", "alpha_2_c1")),

# ML Fit Function to run for each individual  
mxFitFunctionML(vector=TRUE)
) # close model for class 1

class2 <- mxModel(class1,
# latent means  
mxPath(from="one", to=c("eta_1", "eta_2"), arrows=1, 
 free=TRUE, values=c(65, 15), labels=c("alpha_1_c2", "alpha_2_c2")),
 
 name="Class2") # close model

class3 <- mxModel(class1,
# latent means  
mxPath(from="one", to=c("eta_1", "eta_2"), arrows=1, 
 free=TRUE, values=c(30, 15), labels=c("alpha_1_c3", "alpha_2_c3")),
 
 name="Class3") # close model

classRP <- mxMatrix("Full", 3, 1, free=c(TRUE, TRUE, FALSE),
 values=1, lbound=0.001, labels = c("p1", "p2", "p3"), name="RProps")

classP <- mxAlgebra(RProps %x% (1 / sum(RProps)), name="Props")

algObj <- mxAlgebra(-2*sum( log(Props[1,1] %x% Class1.objective + Props[2,1] %x% Class2.objective + Props[3,1] %x% Class3.objective)), name="mixtureObj") 

obj <- mxFitFunctionAlgebra("mixtureObj")

gmm.3.means <- mxModel("2Class Means Growth Mixture Model",
 mxData(observed=ecls_wide, type="raw"),
 class1, class2, class3, classRP, classP, algObj, obj)

gmm.3.means.fit <- mxRun(gmm.3.means)

summary(gmm.3.means.fit)

#free parameters:
#         name   matrix   row   col  Estimate  Std.Error lbound ubound
#1          p1   RProps     1     1  9.936801 1.41573075  0.001       
#2          p2   RProps     2     1  0.227589 0.06621110  0.001       
#3       theta Class1.S wght1 wght1  5.576803 0.17557369              
#4      psi_11 Class1.S eta_1 eta_1 32.723035 1.98229771              
#5      psi_12 Class1.S eta_1 eta_2  6.920611 0.71485600              
#6      psi_22 Class1.S eta_2 eta_2  1.901629 0.37845243              
#7  alpha_1_c1 Class1.M     1 eta_1 43.937206 0.21520684              
#8  alpha_2_c1 Class1.M     1 eta_2  5.619066 0.09481814              
#9  alpha_1_c2 Class2.M     1 eta_1 82.242524 1.92498587              
#10 alpha_2_c2 Class2.M     1 eta_2 14.187956 0.61898490              
#11 alpha_1_c3 Class3.M     1 eta_1 55.866621 0.90511175              
#12 alpha_2_c3 Class3.M     1 eta_2 14.919569 0.42345662              
#
#observed statistics:  4141 
#estimated parameters:  12 
#degrees of freedom:  4129 
#-2 log likelihood:  23401.45 
#number of observations:  1083 
#Information Criteria: 
#      |  df Penalty  |  Parameters Penalty  |  Sample-Size Adjusted
#AIC:      15143.445               23425.45                       NA
#BIC:      -5449.902               23485.30                 23447.18
#Some of your fit indices are missing.
#  To get them, fit saturated and independence models, and include them with
#  summary(yourModel, SaturatedLikelihood=..., IndependenceLikelihood=...). 
#timestamp: 2014-10-20 21:03:51 
#wall clock time: 1.5602 secs 
#optimizer:  CSOLNP 
#OpenMx version number: 2.0.0.3838 
#Need help?  See help(mxSummary) 



############# 2-Class Growth Mixture Model - Means & Covariances #############
class1 <- mxModel("Class1", type="RAM", 
 manifestVars=c("wght1","wght2","wght3","wght4"),
 latentVars=c("eta_1","eta_2"),

# residual variances  
mxPath(from=c("wght1","wght2","wght3","wght4"), arrows=2, 
 free=TRUE, values=6, labels="theta"),

# latent variances and covariance  
mxPath(from=c("eta_1","eta_2"), arrows=2, connect="unique.pairs",
 free=TRUE, values=c(40, 7, 3), labels=c("psi_11_c1", "psi_12_c1", "psi_22_c1")),

# intercept loadings
mxPath(from="eta_1", to=c("wght1","wght2","wght3","wght4"), arrows=1, 
 free=FALSE, values=1),

# slope loadings  
mxPath(from="eta_2", to=c("wght1","wght2","wght3","wght4"), arrows=1,
 free=FALSE, values=c(0, .5, 1, 1.5)),

# latent variable means  
mxPath(from="one", to=c("eta_1", "eta_2"), arrows=1,
 free=TRUE, values=c(44, 6), labels=c("alpha_1_c1", "alpha_2_c1")),

# ML Fit Function to run for each individual  
mxFitFunctionML(vector=TRUE)
) # close model for class 1

class2 <- mxModel(class1,
# latent means  
mxPath(from="one", to=c("eta_1", "eta_2"), arrows=1, 
 free=TRUE, values=c(65, 15), labels=c("alpha_1_c2", "alpha_2_c2")),

# latent variances and covariance  
mxPath(from=c("eta_1","eta_2"), arrows=2, connect="unique.pairs",
 free=TRUE, values=c(40, 7, 3), labels=c("psi_11_c2", "psi_12_c2", "psi_22_c2")),

 name="Class2") # close model

classRP <- mxMatrix("Full", 2, 1, free=c(TRUE, FALSE),
 values=1, lbound=0.001, labels = c("p1", "p2"), name="RProps")

classP <- mxAlgebra(RProps %x% (1 / sum(RProps)), name="Props")

algObj <- mxAlgebra(-2*sum( log(Props[1,1] %x% Class1.objective + Props[2,1] %x% Class2.objective)), name="mixtureObj") 

obj <- mxFitFunctionAlgebra("mixtureObj")

gmm.2.mc <- mxModel("2Class Means Growth Mixture Model",
 mxData(observed=ecls_wide, type="raw"),
 class1, class2, classRP, classP, algObj, obj)

gmm.2.mc.fit <- mxRun(gmm.2.mc)

summary(gmm.2.mc.fit)

#free parameters:
#         name   matrix   row   col   Estimate   Std.Error lbound ubound
#1          p1   RProps     1     1   3.143106  0.35949397  0.001       
#2       theta Class1.S wght1 wght1   5.492942  0.17306491              
#3   psi_11_c1 Class1.S eta_1 eta_1  19.377920  1.48078014              
#4   psi_12_c1 Class1.S eta_1 eta_2   5.961715  0.42810187              
#5   psi_22_c1 Class1.S eta_2 eta_2  -1.316077  0.28105859              
#6  alpha_1_c1 Class1.M     1 eta_1  43.004686  0.20167789              
#7  alpha_2_c1 Class1.M     1 eta_2   5.378898  0.07691104              
#8   psi_11_c2 Class2.S eta_1 eta_1 136.184679 13.36194840              
#9   psi_12_c2 Class2.S eta_1 eta_2  26.154375  4.85389823              
#10  psi_22_c2 Class2.S eta_2 eta_2  28.069479  3.25010583              
#11 alpha_1_c2 Class2.M     1 eta_1  54.562778  0.94251515              
#12 alpha_2_c2 Class2.M     1 eta_2  10.470833  0.46331562              
#
#observed statistics:  4141 
#estimated parameters:  12 
#degrees of freedom:  4129 
#-2 log likelihood:  23142.33 
#number of observations:  1083 
#Information Criteria: 
#      |  df Penalty  |  Parameters Penalty  |  Sample-Size Adjusted
#AIC:      14884.325               23166.33                       NA
#BIC:      -5709.022               23226.18                 23188.06
#Some of your fit indices are missing.
#  To get them, fit saturated and independence models, and include them with
#  summary(yourModel, SaturatedLikelihood=..., IndependenceLikelihood=...). 
#timestamp: 2014-10-20 21:08:06 
#wall clock time: 0.9204478 secs 
#optimizer:  CSOLNP 
#OpenMx version number: 2.0.0.3838 
#Need help?  See help(mxSummary) 



############# 2-Class Growth Mixture Model - Means, Covariances, & Residuals #############
class1 <- mxModel("Class1", type="RAM", 
 manifestVars=c("wght1","wght2","wght3","wght4"),
 latentVars=c("eta_1","eta_2"),

# residual variances  
mxPath(from=c("wght1","wght2","wght3","wght4"), arrows=2, 
 free=TRUE, values=6, labels="theta_c1"),

# latent variances and covariance  
mxPath(from=c("eta_1","eta_2"), arrows=2, connect="unique.pairs",
 free=TRUE, values=c(40, 7, 3), labels=c("psi_11_c1", "psi_12_c1", "psi_22_c1")),

# intercept loadings
mxPath(from="eta_1", to=c("wght1","wght2","wght3","wght4"), arrows=1, 
 free=FALSE, values=1),

# slope loadings  
mxPath(from="eta_2", to=c("wght1","wght2","wght3","wght4"), arrows=1,
 free=FALSE, values=c(0, .5, 1, 1.5)),

# latent variable means  
mxPath(from="one", to=c("eta_1", "eta_2"), arrows=1,
 free=TRUE, values=c(44, 6), labels=c("alpha_1_c1", "alpha_2_c1")),

# ML Fit Function to run for each individual  
mxFitFunctionML(vector=TRUE)
) # close model for class 1

class2 <- mxModel(class1,
# residual variances  
mxPath(from=c("wght1","wght2","wght3","wght4"), arrows=2, 
 free=TRUE, values=6, labels="theta_c2"),

# latent means  
mxPath(from="one", to=c("eta_1", "eta_2"), arrows=1, 
 free=TRUE, values=c(65, 15), labels=c("alpha_1_c2", "alpha_2_c2")),

# latent variances and covariance  
mxPath(from=c("eta_1","eta_2"), arrows=2, connect="unique.pairs",
 free=TRUE, values=c(40, 7, 3), labels=c("psi_11_c2", "psi_12_c2", "psi_22_c2")),

 name="Class2") # close model

classRP <- mxMatrix("Full", 2, 1, free=c(TRUE, FALSE),
 values=1, lbound=0.001, labels = c("p1", "p2"), name="RProps")

classP <- mxAlgebra(RProps %x% (1 / sum(RProps)), name="Props")

algObj <- mxAlgebra(-2*sum( log(Props[1,1] %x% Class1.objective + Props[2,1] %x% Class2.objective)), name="mixtureObj") 

obj <- mxFitFunctionAlgebra("mixtureObj")

gmm.2.mcr <- mxModel("2Class Means Growth Mixture Model",
 mxData(observed=ecls_wide, type="raw"),
 class1, class2, classRP, classP, algObj, obj)

gmm.2.mcr.fit <- mxRun(gmm.2.mcr)

summary(gmm.2.mcr.fit)

#free parameters:
#         name   matrix   row   col   Estimate   Std.Error lbound ubound
#1          p1   RProps     1     1   3.186036  0.31014904  0.001       
#2    theta_c1 Class1.S wght1 wght1   1.465060  0.07033415              
#3   psi_11_c1 Class1.S eta_1 eta_1  24.596601  1.63053146              
#4   psi_12_c1 Class1.S eta_1 eta_2   4.283332  0.46399386              
#5   psi_22_c1 Class1.S eta_2 eta_2   2.183884  0.24688927              
#6  alpha_1_c1 Class1.M     1 eta_1  43.204842  0.20364537              
#7  alpha_2_c1 Class1.M     1 eta_2   5.492414  0.07652841              
#8    theta_c2 Class2.S wght1 wght1  18.509399  1.40484907              
#9   psi_11_c2 Class2.S eta_1 eta_1 134.786887 13.76215846              
#10  psi_12_c2 Class2.S eta_1 eta_2  37.805215  5.03501126              
#11  psi_22_c2 Class2.S eta_2 eta_2  18.698445  3.32525063              
#12 alpha_1_c2 Class2.M     1 eta_1  54.001412  0.83859549              
#13 alpha_2_c2 Class2.M     1 eta_2  10.246117  0.41015229              
#
#observed statistics:  4141 
#estimated parameters:  13 
#degrees of freedom:  4128 
#-2 log likelihood:  21960.96 
#number of observations:  1083 
#Information Criteria: 
#      |  df Penalty  |  Parameters Penalty  |  Sample-Size Adjusted
#AIC:      13704.964               21986.96                       NA
#BIC:      -6883.396               22051.80                 22010.51
#Some of your fit indices are missing.
#  To get them, fit saturated and independence models, and include them with
#  summary(yourModel, SaturatedLikelihood=..., IndependenceLikelihood=...). 
#timestamp: 2014-10-20 21:10:50 
#wall clock time: 1.045253 secs 
#optimizer:  CSOLNP 
#OpenMx version number: 2.0.0.3838 
#Need help?  See help(mxSummary) 


############# 3-Class Growth Mixture Model - Means, Covariances, & Residuals #############
class1 <- mxModel("Class1", type="RAM", 
 manifestVars=c("wght1","wght2","wght3","wght4"),
 latentVars=c("eta_1","eta_2"),

# residual variances  
mxPath(from=c("wght1","wght2","wght3","wght4"), arrows=2, 
 free=TRUE, values=6, labels="theta_c1"),

# latent variances and covariance  
mxPath(from=c("eta_1","eta_2"), arrows=2, connect="unique.pairs",
 free=TRUE, values=c(40, 7, 3), labels=c("psi_11_c1", "psi_12_c1", "psi_22_c1")),

# intercept loadings
mxPath(from="eta_1", to=c("wght1","wght2","wght3","wght4"), arrows=1, 
 free=FALSE, values=1),

# slope loadings  
mxPath(from="eta_2", to=c("wght1","wght2","wght3","wght4"), arrows=1,
 free=FALSE, values=c(0, .5, 1, 1.5)),

# latent variable means  
mxPath(from="one", to=c("eta_1", "eta_2"), arrows=1,
 free=TRUE, values=c(44, 6), labels=c("alpha_1_c1", "alpha_2_c1")),

# ML Fit Function to run for each individual  
mxFitFunctionML(vector=TRUE)
) # close model for class 1

class2 <- mxModel(class1,
# residual variances  
mxPath(from=c("wght1","wght2","wght3","wght4"), arrows=2, 
 free=TRUE, values=6, labels="theta_c2"),

# latent means  
mxPath(from="one", to=c("eta_1", "eta_2"), arrows=1, 
 free=TRUE, values=c(65, 15), labels=c("alpha_1_c2", "alpha_2_c2")),

# latent variances and covariance  
mxPath(from=c("eta_1","eta_2"), arrows=2, connect="unique.pairs",
 free=TRUE, values=c(40, 7, 3), labels=c("psi_11_c2", "psi_12_c2", "psi_22_c2")),

 name="Class2") # close model

class3 <- mxModel(class1,
# residual variances  
mxPath(from=c("wght1","wght2","wght3","wght4"), arrows=2, 
 free=TRUE, values=6, labels="theta_c3"),

# latent means  
mxPath(from="one", to=c("eta_1", "eta_2"), arrows=1, 
 free=TRUE, values=c(30, 15), labels=c("alpha_1_c3", "alpha_2_c3")),

# latent variances and covariance  
mxPath(from=c("eta_1","eta_2"), arrows=2, connect="unique.pairs",
 free=TRUE, values=c(40, 7, 3), labels=c("psi_11_c3", "psi_12_c3", "psi_22_c3")),

 name="Class3") # close model

classRP <- mxMatrix("Full", 3, 1, free=c(TRUE, TRUE, FALSE),
 values=1, lbound=0.001, labels = c("p1", "p2", "p3"), name="RProps")

classP <- mxAlgebra(RProps %x% (1 / sum(RProps)), name="Props")

algObj <- mxAlgebra(-2*sum( log(Props[1,1] %x% Class1.objective + Props[2,1] %x% Class2.objective + Props[3,1] %x% Class3.objective)), name="mixtureObj") 

obj <- mxFitFunctionAlgebra("mixtureObj")

gmm.3.mcr <- mxModel("2Class Means Growth Mixture Model",
 mxData(observed=ecls_wide, type="raw"),
 class1, class2, class3, classRP, classP, algObj, obj)

gmm.3.mcr.fit <- mxRun(gmm.3.mcr)

summary(gmm.3.mcr.fit)

#free parameters:
#         name   matrix   row   col    Estimate   Std.Error lbound ubound
#1          p1   RProps     1     1   1.8166517  0.19070121  0.001       
#2          p2   RProps     2     1   0.1037294  0.02379733  0.001       
#3    theta_c1 Class1.S wght1 wght1   1.1440057  0.06877922              
#4   psi_11_c1 Class1.S eta_1 eta_1  19.6395502  1.35323626              
#5   psi_12_c1 Class1.S eta_1 eta_2   2.8463450  0.35596262              
#6   psi_22_c1 Class1.S eta_2 eta_2   1.2297370  0.17199093              
#7  alpha_1_c1 Class1.M     1 eta_1  42.4302832  0.21212213              
#8  alpha_2_c1 Class1.M     1 eta_2   5.2133780  0.07312559              
#9    theta_c2 Class2.S wght1 wght1  85.5825478 14.54852128              
#10  psi_11_c2 Class2.S eta_1 eta_1 337.2205546 97.93877336              
#11  psi_12_c2 Class2.S eta_1 eta_2  95.3697520 33.44534013              
#12  psi_22_c2 Class2.S eta_2 eta_2  -3.4430267  5.77143059              
#13 alpha_1_c2 Class2.M     1 eta_1  64.4630248  3.65786750              
#14 alpha_2_c2 Class2.M     1 eta_2  12.0599475  1.53801238              
#15   theta_c3 Class3.S wght1 wght1   5.5329638  0.43468036              
#16  psi_11_c3 Class3.S eta_1 eta_1  65.7849241  7.31427772              
#17  psi_12_c3 Class3.S eta_1 eta_2  20.4715128  2.83139292              
#18  psi_22_c3 Class3.S eta_2 eta_2  16.9254557  2.05176467              
#19 alpha_1_c3 Class3.M     1 eta_1  49.9293407  0.59769326              
#20 alpha_2_c3 Class3.M     1 eta_2   8.6572949  0.32063268              
#
#observed statistics:  4141 
#estimated parameters:  20 
#degrees of freedom:  4121 
#-2 log likelihood:  21618.92 
#number of observations:  1083 
#Information Criteria: 
#      |  df Penalty  |  Parameters Penalty  |  Sample-Size Adjusted
#AIC:       13376.92               21658.92                       NA
#BIC:       -7176.53               21758.67                 21695.14
#Some of your fit indices are missing.
#  To get them, fit saturated and independence models, and include them with
#  summary(yourModel, SaturatedLikelihood=..., IndependenceLikelihood=...). 
#timestamp: 2014-10-20 21:27:29 
#wall clock time: 3.931301 secs 
#optimizer:  CSOLNP 
#OpenMx version number: 2.0.0.3838 
#Need help?  See help(mxSummary) 





















